@@ -18,7 +18,7 @@ import json
 import logging
 import os
 from datetime import datetime
-from typing import Dict
+from typing import Dict, List
 
 from load_shedding.providers.eskom import Province, Stage, Suburb, Provider, ProviderError
 
@@ -27,10 +27,7 @@ class ScheduleError(Exception):
     pass
 
 
-def get_schedule(provider: Provider, province: Province, suburb: Suburb, stage: Stage = None, cached: bool = True) -> Dict[Stage, list]:
-    stage_schedule = {}
-    cached_schedule = {}
-
+def get_schedule(provider: Provider, province: Province, suburb: Suburb, stage: Stage = None, cached: bool = True) -> List: # Dict[Stage, list]:
     try:
         os.makedirs('.cache')
     except OSError as e:
@@ -47,33 +44,35 @@ def get_schedule(provider: Provider, province: Province, suburb: Suburb, stage:
     if stage in [None, Stage.UNKNOWN, Stage.NO_LOAD_SHEDDING]:
         raise ScheduleError("{stage}".format(stage=Stage.NO_LOAD_SHEDDING))
 
-    if cached:
-        try:
-            cache_file = ".cache/{suburb_id}.json".format(suburb_id=suburb.id)
-            with open(cache_file, "r") as cache:
-                cached_schedule = json.loads(cache.read(), object_pairs_hook=lambda pairs: {Stage(int(k)).value: v for k, v in pairs})
+    cached_schedules = {}
+    cached_schedule = []
+    try:
+        cache_file = ".cache/{suburb_id}.json".format(suburb_id=suburb.id)
+        with open(cache_file, "r") as cache:
+            cached_schedules = json.loads(cache.read(), object_pairs_hook=lambda pairs: {Stage(int(k)).value: v for k, v in pairs})
+            cached_schedule = cached_schedules.get(stage.value, [])
 
+        if cached and cached_schedule:
             today = datetime.now().date()
-            first = datetime.strptime(cached_schedule.get(Stage.STAGE_1.value)[0][0], "%Y-%m-%d %H:%M").date()
-            if first > today:
+            first = datetime.strptime(cached_schedule[0][0], "%Y-%m-%d %H:%M").date()
+            if first <= today:
                 return cached_schedule
-        except FileNotFoundError as e:
-            logging.log(logging.ERROR, "Unable to get schedule from cache. {e}".format(e=e))
+    except FileNotFoundError as e:
+        logging.log(logging.ERROR, "Unable to get schedule from cache. {e}".format(e=e))
 
     try:
-        for stage in [Stage.STAGE_1, Stage.STAGE_2, Stage.STAGE_3, Stage.STAGE_4]:
-            stage_schedule[stage.value] = provider.get_schedule(province=province, suburb=suburb, stage=stage)
+        schedule = provider.get_schedule(province=province, suburb=suburb, stage=stage)
     except ProviderError as e:
         logging.log(logging.ERROR, "Unable to get schedule from {provider}. {e}".format(provider=provider, e=e))
         if cached_schedule:
-            return cached_schedule
+            return cached_schedule  # best effort
         raise
-
-    cache_file = ".cache/{suburb_id}.json".format(suburb_id=suburb.id)
-    with open(cache_file, "w") as cache:
-        cache.write(json.dumps(stage_schedule))
-
-    return stage_schedule
+    else:
+        cache_file = ".cache/{suburb_id}.json".format(suburb_id=suburb.id)
+        with open(cache_file, "w") as cache:
+            cached_schedules[stage.value] = schedule
+            cache.write(json.dumps(cached_schedules))
+        return schedule
 
 
 def list_to_dict(schedule: list) -> Dict:
